# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-02-02 07:26
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0010_merge_20180202_0726'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='productunique',
            unique_together=set([]),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-18 06:39
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0004_auto_20180117_1745'),
    ]

    operations = [
        migrations.AlterField(
            model_name='attribute',
            name='price',
            field=models.FloatField(default=0, verbose_name='Price'),
        ),
        migrations.AlterField(
            model_name='feature',
            name='price',
            field=models.FloatField(default=0, verbose_name='Price'),
        ),
        migrations.AlterField(
            model_name='featurespecial',
            name='price',
            field=models.FloatField(default=0, verbose_name='Price'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-17 15:28
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('codenerix_products', '0001_initial'),
        ('codenerix_storages', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='productunique',
            name='box',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='products_unique', to='codenerix_storages.StorageBox', verbose_name='Box'),
        ),
        migrations.AddField(
            model_name='productunique',
            name='product_final',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products_unique', to='codenerix_products.ProductFinal', verbose_name='Product final'),
        ),
        migrations.AddField(
            model_name='producttexttextes',
            name='product',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.Product'),
        ),
        migrations.AddField(
            model_name='producttexttexten',
            name='product',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.Product'),
        ),
        migrations.AddField(
            model_name='productrelationsold',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products_related', to='codenerix_products.Product', verbose_name='Product'),
        ),
        migrations.AddField(
            model_name='productrelationsold',
            name='related',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products_related_sold', to='codenerix_products.Product', verbose_name='Products related'),
        ),
        migrations.AddField(
            model_name='productimagetextes',
            name='product_image',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.ProductImage'),
        ),
        migrations.AddField(
            model_name='productimagetexten',
            name='product_image',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.ProductImage'),
        ),
        migrations.AddField(
            model_name='productimage',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products_image', to='codenerix_products.Product', verbose_name='Product'),
        ),
        migrations.AddField(
            model_name='productfinaltextes',
            name='product',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.ProductFinal'),
        ),
        migrations.AddField(
            model_name='productfinaltexten',
            name='product',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.ProductFinal'),
        ),
        migrations.AddField(
            model_name='productfinaloptiontextes',
            name='product_final_option',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.ProductFinalOption'),
        ),
        migrations.AddField(
            model_name='productfinaloptiontexten',
            name='product_final_option',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.ProductFinalOption'),
        ),
        migrations.AddField(
            model_name='productfinaloption',
            name='product_final',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='productfinals_option', to='codenerix_products.ProductFinal', verbose_name='Product Final'),
        ),
        migrations.AddField(
            model_name='productfinaloption',
            name='products_pack',
            field=models.ManyToManyField(related_name='productfinals_optionpack', to='codenerix_products.ProductFinal'),
        ),
        migrations.AddField(
            model_name='productfinalimagetextes',
            name='product_final_image',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.ProductFinalImage'),
        ),
        migrations.AddField(
            model_name='productfinalimagetexten',
            name='product_final_image',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.ProductFinalImage'),
        ),
        migrations.AddField(
            model_name='productfinalimage',
            name='product_final',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='productfinals_image', to='codenerix_products.ProductFinal', verbose_name='Product Final'),
        ),
        migrations.AddField(
            model_name='productfinalattribute',
            name='attribute',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='products_final_attr', to='codenerix_products.Attribute', verbose_name='Attributes'),
        ),
        migrations.AddField(
            model_name='productfinalattribute',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products_final_attr', to='codenerix_products.ProductFinal', verbose_name='Product'),
        ),
        migrations.AddField(
            model_name='productfinal',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products_final', to='codenerix_products.Product', verbose_name='Product'),
        ),
        migrations.AddField(
            model_name='productfinal',
            name='related',
            field=models.ManyToManyField(blank=True, related_name='productsrelated', to='codenerix_products.ProductFinal'),
        ),
        migrations.AddField(
            model_name='productfinal',
            name='related_accesory',
            field=models.ManyToManyField(blank=True, related_name='productsrelatedaccesory', to='codenerix_products.ProductFinal'),
        ),
        migrations.AddField(
            model_name='productfeature',
            name='feature',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='product_features', to='codenerix_products.Feature', verbose_name='Feature'),
        ),
        migrations.AddField(
            model_name='productfeature',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='product_features', to='codenerix_products.Product', verbose_name='Product'),
        ),
        migrations.AddField(
            model_name='productdocumenttextes',
            name='product_document',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.ProductDocument'),
        ),
        migrations.AddField(
            model_name='productdocumenttexten',
            name='product_document',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.ProductDocument'),
        ),
        migrations.AddField(
            model_name='productdocument',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products_document', to='codenerix_products.Product', verbose_name='Product'),
        ),
        migrations.AddField(
            model_name='product',
            name='brand',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='products', to='codenerix_products.Brand', verbose_name='Brand'),
        ),
        migrations.AddField(
            model_name='product',
            name='category',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products', to='codenerix_products.Category', verbose_name='Category'),
        ),
        migrations.AddField(
            model_name='product',
            name='family',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products', to='codenerix_products.Family', verbose_name='Family'),
        ),
        migrations.AddField(
            model_name='product',
            name='feature_special',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='products', to='codenerix_products.FeatureSpecial', verbose_name='Feature special'),
        ),
        migrations.AddField(
            model_name='product',
            name='subcategory',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products', to='codenerix_products.Subcategory', verbose_name='Subcategory'),
        ),
        migrations.AddField(
            model_name='product',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='products', to='codenerix_products.TypeTax', verbose_name='Tax (%)'),
        ),
        migrations.AddField(
            model_name='optionvaluefeaturetextes',
            name='option_value',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.OptionValueFeature'),
        ),
        migrations.AddField(
            model_name='optionvaluefeaturetexten',
            name='option_value',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.OptionValueFeature'),
        ),
        migrations.AddField(
            model_name='optionvaluefeaturespecialtextes',
            name='option_value',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.OptionValueFeatureSpecial'),
        ),
        migrations.AddField(
            model_name='optionvaluefeaturespecialtexten',
            name='option_value',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.OptionValueFeatureSpecial'),
        ),
        migrations.AddField(
            model_name='optionvaluefeaturespecial',
            name='group',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='options_value_feature_special', to='codenerix_products.GroupValueFeatureSpecial', verbose_name='Options value'),
        ),
        migrations.AddField(
            model_name='optionvaluefeature',
            name='group',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='options_value_feature', to='codenerix_products.GroupValueFeature', verbose_name='Options value'),
        ),
        migrations.AddField(
            model_name='optionvalueattributetextes',
            name='option_value',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.OptionValueAttribute'),
        ),
        migrations.AddField(
            model_name='optionvalueattributetexten',
            name='option_value',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.OptionValueAttribute'),
        ),
        migrations.AddField(
            model_name='optionvalueattribute',
            name='group',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='options_value_attribute', to='codenerix_products.GroupValueAttribute', verbose_name='Options value'),
        ),
        migrations.AddField(
            model_name='flagshipproducttextes',
            name='product',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.FlagshipProduct'),
        ),
        migrations.AddField(
            model_name='flagshipproducttexten',
            name='product',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.FlagshipProduct'),
        ),
        migrations.AddField(
            model_name='flagshipproduct',
            name='product_final',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='flagship_products', to='codenerix_products.ProductFinal', verbose_name='Flagship product'),
        ),
        migrations.AddField(
            model_name='featuretextes',
            name='feature',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.Feature'),
        ),
        migrations.AddField(
            model_name='featuretexten',
            name='feature',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.Feature'),
        ),
        migrations.AddField(
            model_name='featurespecialtextes',
            name='feature_special',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.FeatureSpecial'),
        ),
        migrations.AddField(
            model_name='featurespecialtexten',
            name='feature_special',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.FeatureSpecial'),
        ),
        migrations.AddField(
            model_name='featurespecial',
            name='category',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='feature_specials', to='codenerix_products.Category', verbose_name='Category'),
        ),
        migrations.AddField(
            model_name='featurespecial',
            name='family',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='feature_specials', to='codenerix_products.Family', verbose_name='Family'),
        ),
        migrations.AddField(
            model_name='featurespecial',
            name='list_value',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='feature_specials', to='codenerix_products.GroupValueFeatureSpecial', verbose_name='List value'),
        ),
        migrations.AddField(
            model_name='feature',
            name='category',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='features', to='codenerix_products.Category', verbose_name='Category'),
        ),
        migrations.AddField(
            model_name='feature',
            name='family',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='features', to='codenerix_products.Family', verbose_name='Family'),
        ),
        migrations.AddField(
            model_name='feature',
            name='list_value',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='features', to='codenerix_products.GroupValueFeature', verbose_name='List value'),
        ),
        migrations.AddField(
            model_name='familytextes',
            name='family',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.Family'),
        ),
        migrations.AddField(
            model_name='familytexten',
            name='family',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.Family'),
        ),
        migrations.AddField(
            model_name='categorytextes',
            name='category',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.Category'),
        ),
        migrations.AddField(
            model_name='categorytexten',
            name='category',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.Category'),
        ),
        migrations.AddField(
            model_name='category',
            name='family',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='categories', to='codenerix_products.Family', verbose_name='Family'),
        ),
        migrations.AddField(
            model_name='brandtextes',
            name='brand',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.Brand'),
        ),
        migrations.AddField(
            model_name='brandtexten',
            name='brand',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.Brand'),
        ),
        migrations.AddField(
            model_name='attributetextes',
            name='attribute',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.Attribute'),
        ),
        migrations.AddField(
            model_name='attributetexten',
            name='attribute',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.Attribute'),
        ),
        migrations.AddField(
            model_name='attribute',
            name='attribute',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='attributes', to='codenerix_products.Attribute', verbose_name='Attribute'),
        ),
        migrations.AddField(
            model_name='attribute',
            name='category',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='attributes', to='codenerix_products.Category', verbose_name='Category'),
        ),
        migrations.AddField(
            model_name='attribute',
            name='family',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='attributes', to='codenerix_products.Family', verbose_name='Family'),
        ),
        migrations.AddField(
            model_name='attribute',
            name='list_value',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='attributes', to='codenerix_products.GroupValueAttribute', verbose_name='List value'),
        ),
        migrations.AlterUniqueTogether(
            name='productunique',
            unique_together=set([('product_final', 'value')]),
        ),
        migrations.AlterUniqueTogether(
            name='productrelationsold',
            unique_together=set([('product', 'related')]),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-26 16:11
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0007_auto_20180123_1316'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='productfinal',
            name='stock_lock',
        ),
        migrations.RemoveField(
            model_name='productfinal',
            name='stock_real',
        ),
    ]



# -*- coding: utf-8 -*-
#
# django-codenerix-products
#
# Copyright 2017 Centrologic Computational Logistic Center S.L.
#
# Project URL : http://www.codenerix.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from django.contrib import admin
from django.conf import settings

from .models import TypeTax
from .models import Feature, Attribute, FeatureSpecial, Family, Category, Subcategory, Product, ProductRelationSold, ProductImage, ProductDocument, ProductFinal, ProductFeature, ProductUnique, Brand
from .models import GroupValueFeature, GroupValueAttribute, GroupValueFeatureSpecial
from .models import OptionValueFeature, OptionValueAttribute, OptionValueFeatureSpecial
from .models import MODELS, MODELS_BRANDS, MODELS_PRODUCTS, MODELS_SLUG, MODELS_SLIDERS, MODELS_PRODUCTS_FINAL
from .models import ProductFinalOption

admin.site.register(TypeTax)
admin.site.register(Feature)
admin.site.register(Attribute)
admin.site.register(FeatureSpecial)
admin.site.register(Family)
admin.site.register(Category)
admin.site.register(Subcategory)
admin.site.register(Product)
admin.site.register(ProductRelationSold)
admin.site.register(ProductImage)
admin.site.register(ProductDocument)
admin.site.register(ProductFinal)
admin.site.register(ProductFeature)
admin.site.register(ProductUnique)
admin.site.register(Brand)
admin.site.register(GroupValueFeature)
admin.site.register(GroupValueAttribute)
admin.site.register(GroupValueFeatureSpecial)
admin.site.register(OptionValueFeature)
admin.site.register(OptionValueAttribute)
admin.site.register(OptionValueFeatureSpecial)
admin.site.register(ProductFinalOption)

for info in MODELS + MODELS_BRANDS + MODELS_PRODUCTS + MODELS_SLIDERS + MODELS_SLUG + MODELS_PRODUCTS_FINAL:
    model = info[1]
    for lang in settings.LANGUAGES:
        lang_code = lang[0]
        query = "from .models import {}Text{}\n".format(model, lang_code.upper())
        query += "admin.site.register({}Text{})\n".format(model, lang_code.upper())
        exec(query)



# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-17 15:28
from __future__ import unicode_literals

import codenerix.fields
import codenerix.lib.helpers
import codenerix_products.models
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Attribute',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(blank=True, max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name_file', models.CharField(blank=True, max_length=254, null=True, verbose_name='Name')),
                ('type_value', models.CharField(choices=[('F', 'Sin validacion'), ('B', 'Boolean'), ('O', 'Lista de opciones')], default='F', max_length=2, verbose_name='Type value')),
                ('price', models.FloatField(default=0, verbose_name='Price')),
                ('type_price', models.CharField(choices=[('P', 'Porcentaje sobre el precio del producto'), ('I', 'Incremento sobre el precio del producto'), ('F', 'Precio final')], default='P', max_length=2, verbose_name='Type price')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='AttributeTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='AttributeTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Brand',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(blank=True, max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name_file', models.CharField(blank=True, max_length=254, null=True, verbose_name='Name')),
                ('outstanding', models.BooleanField(default=True, verbose_name='Outstanding')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
                ('show_menu', models.BooleanField(default=True, verbose_name='Show menu')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='BrandTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('description_short', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description short')),
                ('description_long', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description long')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(blank=True, max_length=250, null=True, verbose_name='Name')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='BrandTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('description_short', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description short')),
                ('description_long', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description long')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(blank=True, max_length=250, null=True, verbose_name='Name')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('code', models.CharField(blank=True, max_length=250, null=True, unique=True, verbose_name='Code')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('show_menu', models.BooleanField(default=True, verbose_name='Show menu')),
                ('show_only_product_stock', models.BooleanField(default=True, verbose_name='Show only products in stock')),
                ('image', codenerix.fields.ImageAngularField(blank=True, help_text='Se aconseja un tamaño comprendido entre 1200px y 2000px', max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('icon', codenerix.fields.ImageAngularField(blank=True, help_text='Se aconseja que sea una imagen superior a 200px transparente y en formato png o svg', max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Icon')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CategoryTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CategoryTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Family',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(blank=True, max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name_file', models.CharField(blank=True, max_length=254, null=True, verbose_name='Name')),
                ('code', models.CharField(blank=True, max_length=250, null=True, unique=True, verbose_name='Code')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
                ('show_menu', models.BooleanField(default=True, verbose_name='Show menu')),
                ('icon', codenerix.fields.ImageAngularField(blank=True, help_text='Se aconseja que sea una imagen superior a 200px transparente y en formato png o svg', max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Icon')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FamilyTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FamilyTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Feature',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(blank=True, max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name_file', models.CharField(blank=True, max_length=254, null=True, verbose_name='Name')),
                ('type_value', models.CharField(choices=[('F', 'Sin validacion'), ('B', 'Boolean'), ('O', 'Lista de opciones')], default='F', max_length=2, verbose_name='Type value')),
                ('price', models.FloatField(default=0, verbose_name='Price')),
                ('type_price', models.CharField(choices=[('P', 'Porcentaje sobre el precio del producto'), ('I', 'Incremento sobre el precio del producto'), ('F', 'Precio final')], default='P', max_length=2, verbose_name='Type price')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FeatureSpecial',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(blank=True, max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name_file', models.CharField(blank=True, max_length=254, null=True, verbose_name='Name')),
                ('type_value', models.CharField(choices=[('F', 'Sin validacion'), ('B', 'Boolean'), ('O', 'Lista de opciones')], default='F', max_length=2, verbose_name='Type value')),
                ('price', models.FloatField(default=0, verbose_name='Price')),
                ('type_price', models.CharField(choices=[('P', 'Porcentaje sobre el precio del producto'), ('I', 'Incremento sobre el precio del producto'), ('F', 'Precio final')], default='P', max_length=2, verbose_name='Type price')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
                ('unique', models.BooleanField(default=True, verbose_name='The value must unique')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FeatureSpecialTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FeatureSpecialTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FeatureTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FeatureTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FlagshipProduct',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(max_length=200, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name_file', models.CharField(blank=True, max_length=254, null=True, verbose_name='Name')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('view_video', models.BooleanField(default=False, verbose_name='View video')),
                ('orientazion', models.CharField(choices=[('R', 'Right'), ('L', 'Left')], default='R', max_length=2, verbose_name='Orientazion')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
            bases=(codenerix_products.models.CustomQueryMixin, models.Model),
        ),
        migrations.CreateModel(
            name='FlagshipProductTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('title', models.CharField(max_length=250, verbose_name='Text alternavive image')),
                ('description', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FlagshipProductTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('title', models.CharField(max_length=250, verbose_name='Text alternavive image')),
                ('description', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='GroupValueAttribute',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('name', models.CharField(blank=True, max_length=250, null=True, unique=True, verbose_name='Name')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='GroupValueFeature',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('name', models.CharField(blank=True, max_length=250, null=True, unique=True, verbose_name='Name')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='GroupValueFeatureSpecial',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('name', models.CharField(blank=True, max_length=250, null=True, unique=True, verbose_name='Name')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueAttribute',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueAttributeTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueAttributeTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueFeature',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueFeatureSpecial',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueFeatureSpecialTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueFeatureSpecialTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueFeatureTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueFeatureTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Product',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('model', models.CharField(blank=True, max_length=250, null=True, verbose_name='Model')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('code', models.CharField(max_length=250, unique=True, verbose_name='Code')),
                ('price_base', models.FloatField(default=0, verbose_name='Price base')),
                ('of_sales', models.BooleanField(default=True, verbose_name='Sales')),
                ('of_purchase', models.BooleanField(default=True, verbose_name='Purchase')),
                ('force_stock', models.BooleanField(default=True, verbose_name='Force stock')),
                ('url_video', models.CharField(blank=True, max_length=250, null=True, verbose_name='Url Video')),
                ('packing_cost', models.FloatField(default=0, verbose_name='Packing cost')),
                ('weight', models.FloatField(default=0, verbose_name='Weight')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
            bases=(codenerix_products.models.CustomQueryMixin, models.Model),
        ),
        migrations.CreateModel(
            name='ProductDocument',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('doc_path', codenerix.fields.FileAngularField(max_length=200, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Doc Path')),
                ('name_file', models.CharField(max_length=254, verbose_name='Name')),
                ('public', models.BooleanField(default=False, verbose_name='Public')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductDocumentTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductDocumentTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFeature',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('value', models.CharField(max_length=80, verbose_name='Value')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinal',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('offer', models.BooleanField(default=False, verbose_name='Offer')),
                ('outstanding', models.BooleanField(default=False, verbose_name='Outstanding')),
                ('most_sold', models.BooleanField(default=False, verbose_name='Most sold')),
                ('stock_real', models.FloatField(default=0, editable=False, verbose_name='Stock real')),
                ('stock_lock', models.FloatField(default=0, editable=False, verbose_name='Stock lock')),
                ('price_base', models.FloatField(default=0, editable=False, verbose_name='Price base')),
                ('price', models.FloatField(default=0, editable=False, verbose_name='Price')),
                ('ean13', models.CharField(blank=True, max_length=13, null=True, verbose_name='EAN-13')),
                ('reviews_value', models.FloatField(default=0, editable=False, verbose_name='Reviews')),
                ('reviews_count', models.IntegerField(default=0, editable=False, verbose_name='Reviews count')),
                ('sample', models.BooleanField(default=False, help_text='If this option is checked the product can not be sold', verbose_name='Sample')),
                ('code', models.CharField(blank=True, help_text='If it is empty, code is equal to code product', max_length=250, null=True, unique=True, verbose_name='Code')),
                ('price_base_local', models.FloatField(blank=True, help_text='If it is empty, price base is equal to price base of product', null=True, verbose_name='Price base')),
                ('packing_cost', models.FloatField(blank=True, help_text='If it is empty, packing cost is equal to packing cost of product', null=True, verbose_name='Packing cost')),
                ('weight', models.FloatField(blank=True, help_text='If it is empty, weight is equal to weight of product', null=True, verbose_name='Weight')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
            bases=(codenerix_products.models.CustomQueryMixin, models.Model),
        ),
        migrations.CreateModel(
            name='ProductFinalAttribute',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('value', models.CharField(max_length=80, verbose_name='Value')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinalImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(max_length=200, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name_file', models.CharField(blank=True, max_length=254, null=True, verbose_name='Name')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('principal', models.BooleanField(default=False, verbose_name='Principal')),
                ('flagship_product', models.BooleanField(default=False, verbose_name='Flagship product')),
                ('outstanding', models.BooleanField(default=False, verbose_name='Outstanding')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinalImageTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinalImageTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinalOption',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('active', models.BooleanField(default=True, verbose_name='Active')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinalOptionTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinalOptionTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinalTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('description_short', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description short')),
                ('description_long', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description long')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(blank=True, max_length=250, null=True, verbose_name='Name')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('tags', models.TextField(blank=True, null=True, verbose_name='TAGs')),
                ('description_sample', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Sample description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinalTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('description_short', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description short')),
                ('description_long', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description long')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(blank=True, max_length=250, null=True, verbose_name='Name')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('tags', models.TextField(blank=True, null=True, verbose_name='TAGs')),
                ('description_sample', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Sample description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(max_length=200, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name_file', models.CharField(blank=True, max_length=254, null=True, verbose_name='Name')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('principal', models.BooleanField(default=False, verbose_name='Principal')),
                ('flagship_product', models.BooleanField(default=False, verbose_name='Flagship product')),
                ('outstanding', models.BooleanField(default=False, verbose_name='Outstanding')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductImageTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductImageTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductRelationSold',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('hits', models.SmallIntegerField(blank=True, null=True, verbose_name='Hits')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductTextTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('description_short', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description short')),
                ('description_long', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description long')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(blank=True, max_length=250, null=True, verbose_name='Name')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('tags', models.TextField(blank=True, null=True, verbose_name='TAGs')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductTextTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('description_short', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description short')),
                ('description_long', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description long')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(blank=True, max_length=250, null=True, verbose_name='Name')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('tags', models.TextField(blank=True, null=True, verbose_name='TAGs')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductUnique',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('value', models.CharField(blank=True, max_length=80, null=True, verbose_name='Value')),
                ('stock_real', models.FloatField(default=0, verbose_name='Stock real')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Subcategory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('code', models.CharField(blank=True, max_length=250, null=True, unique=True, verbose_name='Code')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('show_menu', models.BooleanField(default=True, verbose_name='Show menu')),
                ('show_brand', models.BooleanField(default=True, verbose_name='Show brand (for menu)')),
                ('outstanding', models.BooleanField(default=False, verbose_name='Outstanding')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
                ('image', codenerix.fields.ImageAngularField(blank=True, help_text='Se aconseja un tamaño comprendido entre 1200px y 2000px', max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('icon', codenerix.fields.ImageAngularField(blank=True, help_text='Se aconseja que sea una imagen superior a 200px transparente y en formato png o svg', max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Icon')),
                ('category', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='subcategory', to='codenerix_products.Category', verbose_name='Category')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SubcategoryTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
                ('subcategory', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.Subcategory')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SubcategoryTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
                ('subcategory', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.Subcategory')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='TypeTax',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('tax', models.FloatField(validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(100)], verbose_name='Tax (%)')),
                ('name', models.CharField(max_length=250, unique=True, verbose_name='Name')),
                ('default', models.BooleanField(default=False, verbose_name='Default')),
                ('recargo_equivalencia', models.FloatField(validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(100)], verbose_name='Recargo de equivalencia (%)')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
    ]



# -*- coding: utf-8 -*-
#
# django-codenerix-products
#
# Copyright 2017 Centrologic Computational Logistic Center S.L.
#
# Project URL : http://www.codenerix.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from django import forms
from django.utils.translation import ugettext_lazy as _
from django.forms.utils import ErrorList
from django.conf import settings

from codenerix.forms import GenModelForm
from codenerix.widgets import MultiStaticSelect, DynamicSelect
from codenerix_extensions.helpers import get_language_database

from .models import TypeTax
from .models import Feature, Attribute, FeatureSpecial, ProductFinalAttribute
from .models import Family, Category, Subcategory, Brand
from .models import Product, ProductFinal, FlagshipProduct
from .models import ProductRelationSold, ProductImage, ProductDocument, ProductFeature, ProductUnique, ProductFinalImage
from .models import GroupValueFeature, GroupValueAttribute, GroupValueFeatureSpecial, OptionValueFeature, OptionValueAttribute, OptionValueFeatureSpecial
from .models import MODELS, MODELS_SLUG, MODELS_BRANDS, MODELS_PRODUCTS, MODELS_PRODUCTS_FINAL, MODELS_SLIDERS, TYPE_VALUES, TYPE_VALUE_LIST, TYPE_VALUE_BOOLEAN, TYPE_VALUE_FREE
from .models import ProductFinalOption


class TypeTaxForm(GenModelForm):
    class Meta:
        model = TypeTax
        exclude = []

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['name', 6],
                ['tax', 3],
                ['default', 3],
                ['recargo_equivalencia', 4],

            )
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (
                _('Details'), 12,
                ['name', 6],
                ['tax', 3],
                ['default', 3],
                ['recargo_equivalencia', 4],
            )
        ]
        return g


class FeatureForm(GenModelForm):
    class Meta:
        model = Feature
        exclude = ['name_file', ]
        autofill = {
            'FeatureForm_category': ['select', 3, 'CDNX_products_categorys_foreign', 'FeatureForm_family', ],
        }

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['family', 3],
                ['category', 3],
                ['order', 3],
                ['public', 3],
                ['type_price', 3],
                ['price', 3],
                ['type_value', 3],
                ['list_value', 3],
                ['image', 6],
            )
        ]
        return g

    def clean(self):
        cleaned_data = super(FeatureForm, self).clean()
        type_value = cleaned_data.get("type_value")
        list_value = cleaned_data.get("list_value")

        if type_value == TYPE_VALUES[2][0] and list_value is None:
            self._errors["type_value"] = ErrorList([_("Debe elegir un lista de valores")])


class AttributeForm(GenModelForm):
    class Meta:
        model = Attribute
        exclude = ['name_file', ]
        autofill = {
            'AttributeForm_category': ['select', 3, 'CDNX_products_categorys_foreign', 'AttributeForm_family', ],
        }

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['family', 3],
                ['category', 3],
                ['order', 3],
                ['public', 3],
                ['type_price', 3],
                ['price', 3],
                ['type_value', 3],
                ['list_value', 3],
                ['image', 6],
                ['attribute', 6],
            )
        ]
        return g

    def clean(self):
        cleaned_data = super(AttributeForm, self).clean()
        type_value = cleaned_data.get("type_value")
        list_value = cleaned_data.get("list_value")

        if type_value == TYPE_VALUES[2][0] and list_value is None:
            self._errors["type_value"] = ErrorList([_("Debe elegir un lista de valores")])


class FeatureSpecialForm(GenModelForm):
    class Meta:
        model = FeatureSpecial
        exclude = ['name_file', ]
        autofill = {
            'FeatureSpecialForm_category': ['select', 3, 'CDNX_products_categorys_foreign', 'FeatureSpecialForm_family', ],
        }

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['family', 3],
                ['category', 3],
                ['order', 2],
                ['public', 2],
                ['unique', 2],
                ['type_price', 3],
                ['price', 3],
                ['type_value', 3],
                ['list_value', 3],
                ['image', 6],
            )
        ]
        return g

    def clean(self):
        cleaned_data = super(FeatureSpecialForm, self).clean()
        type_value = cleaned_data.get("type_value")
        list_value = cleaned_data.get("list_value")

        if type_value == TYPE_VALUES[2][0] and list_value is None:
            self._errors["type_value"] = ErrorList([_("Debe elegir un lista de valores")])


class FamilyForm(GenModelForm):
    class Meta:
        model = Family
        exclude = ['name_file', ]

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['order', 2],
                ['code', 4],
                ['public', 3],
                ['show_menu', 3],
                ['icon', 6],
                ['image', 6],
            )
        ]
        return g


class CategoryForm(GenModelForm):
    class Meta:
        model = Category
        exclude = []

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['order', 2],
                ['code', 2],
                ['family', 4],
                ['public', 1],
                ['show_menu', 1],
                ['show_only_product_stock', 2],
                ['icon', 6],
                ['image', 6],
            )
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (
                _('Details'), 12,
                ['order', 2],
                ['code', 4],
                ['family', 4],
                ['public', 1],
                ['show_menu', 1],
                ['show_only_product_stock', 2],
                ['image', 6],
                ['icon', 6],
            )
        ]
        return g


class BrandForm(GenModelForm):
    class Meta:
        model = Brand
        exclude = ['name_file', ]

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['order', 2],
                ['outstanding', 2],
                ['show_menu', 2],
                ['image', 6],
            )
        ]
        return g


class SubcategoryForm(GenModelForm):
    class Meta:
        model = Subcategory
        exclude = []

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['order', 2],
                ['code', 3],
                ['category', 3],
                ['public', 1],
                ['show_menu', 1],
                ['show_brand', 1],
                ['outstanding', 1],
                ['icon', 6],
                ['image', 6],
            )
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (
                _('Details'), 12,
                ['order', 2],
                ['code', 3],
                ['category', 3],
                ['public', 1],
                ['show_menu', 1],
                ['show_brand', 1],
                ['outstanding', 1],
                ['icon', 6],
                ['image', 6],
            )
        ]
        return g


class SubcategoryOwnForm(GenModelForm):
    class Meta:
        model = Subcategory
        exclude = ['category']

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['order', 3],
                ['code', 3],
                ['public', 2],
                ['show_menu', 2],
                ['outstanding', 2],
                ['icon', 6],
                ['image', 6],
            )
        ]
        return g


class ProductFormCreate(GenModelForm):
    class Meta:
        model = Product
        exclude = []
        autofill = {
            'ProductFormCreate_category': ['select', 3, 'CDNX_products_categorys_foreign', 'ProductFormCreate_family', ],
            'ProductFormCreate_subcategory': ['select', 3, 'CDNX_products_subcategorys_foreign', 'ProductFormCreate_category', ],
        }

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['code', 4],
                ['price_base', 3],
                ['public', 1],
                ['of_sales', 1],
                ['of_purchase', 1],
                ['force_stock', 1],
                ['caducable', 1],
                ['model', 4],
                ['brand', 4],
                ['feature_special', 4],
                ['family', 4],
                ['category', 4],
                ['subcategory', 4],
                ['tax', 4],
                ['url_video', 4],
            ),
            (
                _('Packaging information'), 12,
                ['packing_cost', 4],
                ['weight', 4],
            )
        ]
        return g


class ProductFormCreateCustom(GenModelForm):
    pass_to_final = forms.BooleanField(label=_("Create product final"), required=False, initial=True)
    ean13 = forms.CharField(label=_("EAN-13"), max_length=13, required=False)

    class Meta:
        model = Product
        exclude = []
        autofill = {
            'ProductFormCreateCustom_category': ['select', 3, 'CDNX_products_categorys_foreign', 'ProductFormCreateCustom_family', ],
            'ProductFormCreateCustom_subcategory': ['select', 3, 'CDNX_products_subcategorys_foreign', 'ProductFormCreateCustom_category', ],
        }

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['code', 3],
                ['price_base', 2],
                ['pass_to_final', 2],
                ['public', 1],
                ['of_sales', 1],
                ['of_purchase', 1],
                ['force_stock', 1],
                ['caducable', 1],
                ['model', 4],
                ['brand', 4],
                ['feature_special', 4],
                ['family', 4],
                ['category', 4],
                ['subcategory', 4],
                ['tax', 4],
                ['url_video', 4],
                ['ean13', 4],
            ),
            (
                _('Packaging information'), 12,
                ['packing_cost', 4],
                ['weight', 4],
            )
        ]
        return g


class ProductForm(GenModelForm):
    class Meta:
        model = Product
        exclude = ['related', ]
        autofill = {
            'ProductForm_category': ['select', 3, 'CDNX_products_categorys_foreign', 'ProductForm_family', ],
            'ProductForm_subcategory': ['select', 3, 'CDNX_products_subcategorys_foreign', 'ProductForm_category', ],
        }

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['code', 4],
                ['price_base', 3],
                ['public', 1],
                ['of_sales', 1],
                ['of_purchase', 1],
                ['force_stock', 1],
                ['caducable', 1],
                ['model', 4],
                ['brand', 4],
                ['feature_special', 4],
                ['family', 4],
                ['category', 4],
                ['subcategory', 4],
                ['tax', 4],
                ['url_video', 4],
            ),
            (
                _('Packaging information'), 12,
                ['packing_cost', 4],
                ['weight', 4],
            )
        ]
        return g

    @staticmethod
    def __groups_details__():
        lang = get_language_database()
        g = [
            (
                _('Details'), 6,
                ['pk', 6],
                ['model', 6],
                ['brand', 6],
                ['family', 6],
                ['category', 6],
                ['subcategory', 6],
                ['public', 6],
                ['code', 6],
                ['price_base', 6],
                ['of_sales', 6],
                ['of_purchase', 6],
                ['force_stock', 6],
                ['tax', 6],
                ['url_video', 6],
                ['feature_special', 6],
                ['packing_cost', 6],
                ['weight', 6],
                ['caducable', 6],
            ),
            (
                _('Information'), 6,
                ["{}__name".format(lang), 6],
                ["{}__slug".format(lang), 6],
                ["{}__public".format(lang), 6],
                ["{}__meta_title".format(lang), 6],
                ["{}__meta_description".format(lang), 6],
            )
        ]
        return g


class ProductRelatedSubForm(GenModelForm):
    new_product = forms.ModelChoiceField(queryset=Product.objects.all(), label=_('Product'), required=True)

    class Meta:
        model = Product
        fields = ['new_product', ]
        """
        autofill = {
            'new_product': ['select', 3, 'limittrials_foreign', '__pk__'],
        }
        """

    # Esto es un intento de que solo muestre las que no tienen riesgo de provocar bucles. Se deja para más adelante.
    def __init__(self, *args, **kwargs):
        self.instance = kwargs.get('instance', None)
        return super(ProductRelatedSubForm, self).__init__(*args, **kwargs)

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['new_product', 12],
            )
        ]
        return g


class ProductRelationSoldForm(GenModelForm):
    class Meta:
        model = ProductRelationSold
        exclude = []

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['product', 6],
                ['related', 6],
                ['hits', 6],
            )
        ]
        return g


class ProductImageForm(GenModelForm):
    class Meta:
        model = ProductImage
        exclude = ['product', 'name_file', ]

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['order', 4],
                ['public', 2],
                ['principal', 2],
                ['flagship_product', 2],
                ['outstanding', 2],
                ['image', 12],
            )
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (
                _('Details'), 12,
                ['product', 6],
                ['order', 6],
                ['public', 6],
                ['principal', 6],
                ['flagship_product', 4],
                ['outstanding', 4],
                ['image', 6],
                ['name_file', 6],
            )
        ]
        return g


class ProductFinalImageForm(GenModelForm):
    class Meta:
        model = ProductFinalImage
        exclude = ['product_final', 'name_file', ]

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['order', 4],
                ['public', 2],
                ['principal', 2],
                ['flagship_product', 2],
                ['outstanding', 2],
                ['image', 12],
            )
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (
                _('Details'), 12,
                ['product_final', 6],
                ['order', 6],
                ['public', 6],
                ['principal', 6],
                ['flagship_product', 4],
                ['outstanding', 4],
                ['image', 6],
                ['name_file', 6],
            )
        ]
        return g


class ProductDocumentForm(GenModelForm):
    class Meta:
        model = ProductDocument
        exclude = ['product', 'name_file', ]

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['doc_path', 9],
                ['public', 3],
            )
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (
                _('Details'), 12,
                ['product', 6],
                ['name_file', 6],
                ['public', 6],
                ['doc_path', 6],
            )
        ]
        return g


class ProductFinalFormCreate(GenModelForm):
    related = forms.ModelMultipleChoiceField(
        queryset=ProductFinal.objects.all(),
        label=_('Related products'),
        required=False,
        widget=MultiStaticSelect(
            attrs={'manytomany': True, }
        )
    )

    related_accesory = forms.ModelMultipleChoiceField(
        queryset=ProductFinal.objects.all(),
        label=_('Related accesory'),
        required=False,
        widget=MultiStaticSelect(
            attrs={'manytomany': True, }
        )
    )

    class Meta:
        model = ProductFinal
        exclude = []
        autofill = {
            'ProductFinalFormCreate_product': ['select', 3, 'CDNX_products_products_foreign'],
        }

    def __groups__(self):
        g = [(
            _('Details'), 12,
            ["product", 4],
            ["offer", 2],
            ["outstanding", 2],
            ['most_sold', 2],
            ["sample", 2],
            ["code", 4],
            ["price_base_local", 4],
            ["ean13", 4],
            ["related", 6],
            ["related_accesory", 6],
        ), (
            _('Packaging information'), 12,
            ['packing_cost', 4],
            ['weight', 4],
        )]
        return g


class ProductFinalFormCreateModal(ProductFinalFormCreate):
    class Meta:
        model = ProductFinal
        exclude = ['product', ]
        autofill = {
            'ProductFinalFormCreate_product': ['select', 3, 'CDNX_products_products_foreign'],
        }

    def __groups__(self):
        g = [(
            _('Details'), 12,
            ["offer", 3],
            ["outstanding", 3],
            ['most_sold', 3],
            ["sample", 3],
            ["code", 4],
            ["price_base_local", 4],
            ["ean13", 4],
            ["related", 6],
            ["related_accesory", 6],
        ), (
            _('Packaging information'), 12,
            ['packing_cost', 4],
            ['weight', 4],
        )]
        return g


class ProductFinalForm(GenModelForm):
    class Meta:
        model = ProductFinal
        exclude = ['related', 'related_accesory']
        autofill = {
            'ProductFinalFormCreate_product': ['select', 3, 'CDNX_products_products_foreign'],  # Al usar un multiform, el nombre es distinto.
        }

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ["product", 4],
                ["offer", 2],
                ["outstanding", 2],
                ['most_sold', 2],
                ['sample', 2],
                ["code", 4],
                ["price_base_local", 4],
                ["ean13", 4],
            ), (
                _('Packaging information'), 12,
                ['packing_cost', 4],
                ['weight', 4],
            )
        ]
        return g

    @staticmethod
    def __groups_details__():
        lang = get_language_database()
        g = [
            (
                _('Details'), 6,
                ['pk', 6],
                ["code", 4],
                ["product", 6],
                ["price_base_local", 4],
                ["offer", 3],
                ["outstanding", 3],
                ["price", 6],
                ["reviews_value", 6],
                ["reviews_count", 6],
                ["ean13", 6],
                ["most_sold", 6],
                ["sample", 6],
                ['packing_cost', 4],
                ['weight', 4],
            ),
            (
                _('Information'), 6,
                ["{}__name".format(lang), 6],
                ["{}__slug".format(lang), 6],
                ["{}__public".format(lang), 6],
                ["{}__meta_title".format(lang), 6],
                ["{}__meta_description".format(lang), 6],
            )
        ]
        return g


class ProductFinalRelatedSubForm(GenModelForm):
    new_product = forms.ModelChoiceField(queryset=ProductFinal.objects.all(), label=_('Product'), required=True,)

    class Meta:
        model = ProductFinal
        fields = ['new_product', ]

    # Esto es un intento de que solo muestre las que no tienen riesgo de provocar bucles. Se deja para más adelante.
    def __init__(self, *args, **kwargs):
        self.instance = kwargs.get('instance', None)
        return super(ProductFinalRelatedSubForm, self).__init__(*args, **kwargs)

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['new_product', 12],)
        ]
        return g


class ProductFinalAttributeForm(GenModelForm):
    product_pk = forms.CharField(widget=forms.HiddenInput())
    value = forms.CharField(widget=forms.HiddenInput(), required=False)
    value_free = forms.CharField(label=_("Value"), max_length=80, required=False)
    value_bool = forms.BooleanField(label=_("Value"), required=False)
    value_list = forms.CharField(label=_("Value"), required=False, widget=DynamicSelect())

    class Meta:
        model = ProductFinalAttribute
        exclude = ["product", "product_pk", ]
        autofill = {
            'attribute': ['select', 3, 'CDNX_products_attributes_foreign', 'product_pk'],
            'value_list': ['select', 3, 'CDNX_products_OptionValueAttributes_foreign', 'product_pk', 'attribute'],
        }

    def __init__(self, *args, **kwargs):
        product_pk = kwargs.get('product_pk', None)
        value_bool = kwargs.get('value_bool', None)
        value_free = kwargs.get('value_free', None)
        value_list = kwargs.get('value_list', None)
        if product_pk:
            kwargs.pop('product_pk')
        if value_bool:
            kwargs.pop('value_bool')
        if value_free:
            kwargs.pop('value_free')
        if value_list:
            kwargs.pop('value_list')
        r = super(ProductFinalAttributeForm, self).__init__(*args, **kwargs)
        self.initial['product_pk'] = product_pk
        self.initial['value_bool'] = value_bool
        self.initial['value_free'] = value_free
        self.initial['value_list'] = value_list
        return r

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ["attribute", 12],
                ['value_free', 12, None, None, None, None, None, None, ["ng-show=show_optionvalue('{}')".format(TYPE_VALUE_FREE)]],
                ['value_bool', 12, None, None, None, None, None, None, ["ng-show=show_optionvalue('{}')".format(TYPE_VALUE_BOOLEAN)]],
                ['value_list', 12, None, None, None, None, None, None, ["ng-show=show_optionvalue('{}')".format(TYPE_VALUE_LIST)]],
            )
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (
                _('Details'), 12,
                ["attribute", 6],
                ["value", 6],
            )
        ]
        return g


class ProductFeatureForm(GenModelForm):
    product_pk = forms.CharField(widget=forms.HiddenInput())
    value = forms.CharField(widget=forms.HiddenInput(), required=False)
    value_free = forms.CharField(label=_("Value"), max_length=80, required=False)
    value_bool = forms.BooleanField(label=_("Value"), required=False)
    value_list = forms.CharField(label=_("Value"), required=False, widget=DynamicSelect())

    class Meta:
        model = ProductFeature
        exclude = ["product", "product_pk", ]
        autofill = {
            'feature': ['select', 3, 'CDNX_products_features_foreign', 'product_pk'],
            'value_list': ['select', 3, 'CDNX_products_OptionValueFeatures_foreign', 'product_pk', 'feature'],
        }

    def __init__(self, *args, **kwargs):
        product_pk = kwargs.get('product_pk', None)
        value_bool = kwargs.get('value_bool', None)
        value_free = kwargs.get('value_free', None)
        value_list = kwargs.get('value_list', None)
        if product_pk:
            kwargs.pop('product_pk')
        if value_bool:
            kwargs.pop('value_bool')
        if value_free:
            kwargs.pop('value_free')
        if value_list:
            kwargs.pop('value_list')
        r = super(ProductFeatureForm, self).__init__(*args, **kwargs)
        self.initial['product_pk'] = product_pk
        self.initial['value_bool'] = value_bool
        self.initial['value_free'] = value_free
        self.initial['value_list'] = value_list
        return r

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['feature', 12],
                ['value_free', 12, None, None, None, None, None, None, ["ng-show=show_optionvalue('{}')".format(TYPE_VALUE_FREE)]],
                ['value_bool', 12, None, None, None, None, None, None, ["ng-show=show_optionvalue('{}')".format(TYPE_VALUE_BOOLEAN)]],
                ['value_list', 12, None, None, None, None, None, None, ["ng-show=show_optionvalue('{}')".format(TYPE_VALUE_LIST)]],
            )
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (
                _('Details'), 12,
                ['product', 6],
                ['feature', 6],
                ['value', 6],
            )
        ]
        return g


class ProductUniqueForm(GenModelForm):
    product_pk = forms.CharField(widget=forms.HiddenInput())

    class Meta:
        model = ProductUnique
        exclude = ['product_final', "product_pk", ]

    def __init__(self, *args, **kwargs):
        product_pk = kwargs.get('product_pk', None)
        if product_pk:
            kwargs.pop('product_pk')
        super(ProductUniqueForm, self).__init__(*args, **kwargs)
        self.initial['product_pk'] = product_pk
        return None

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['value', 6],
                ['stock_original', 6],
                ['box', 6],
            )
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (
                _('Details'), 12,
                ['product_final', 6],
                ['product_final__product__feature_special', 6],
                ['value', 6],
                ['stock_original', 6],
                ['stock_real', 6],
                ['stock_locked', 6],
            )
        ]
        return g


class GroupValuesForm(GenModelForm):
    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['name', 6],
            )
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (
                _('Details'), 12,
                ['name', 6],
            )
        ]
        return g


class GroupValueFeatureForm(GroupValuesForm):
    class Meta:
        model = GroupValueFeature
        exclude = []


class GroupValueAttributeForm(GroupValuesForm):
    class Meta:
        model = GroupValueAttribute
        exclude = []


class GroupValueFeatureSpecialForm(GroupValuesForm):
    class Meta:
        model = GroupValueFeatureSpecial
        exclude = []


class OptionValuesForm(GenModelForm):
    def __groups__(self):
        g = []
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (
                _('Details'), 12,
                ['group', 6],
            )
        ]
        return g


class OptionValueFeatureForm(OptionValuesForm):
    class Meta:
        model = OptionValueFeature
        exclude = ['group', ]


class OptionValueAttributeForm(OptionValuesForm):
    class Meta:
        model = OptionValueAttribute
        exclude = ['group', ]


class OptionValueFeatureSpecialForm(OptionValuesForm):
    class Meta:
        model = OptionValueFeatureSpecial
        exclude = ['group', ]


class FlagshipProductForm(GenModelForm):
    class Meta:
        model = FlagshipProduct
        exclude = ['name_file', ]

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['product_final', 6],
                ['public', 3],
                ['view_video', 3],
                ['orientazion', 6],
                ['image', 6],
            )
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (
                _('Details'), 12,
                ['product_final', 6],
                ['public', 6],
                ['view_video', 6],
                ['orientazion', 6],
                ['image', 6],
                ['name_file', 6],
            )
        ]
        return g

    def clean(self):
        if self.cleaned_data['view_video'] and not self.cleaned_data['product_final'].product.url_video:
            msg = _("The select product haven't video url")
            self._errors["view_video"] = ErrorList([_(msg)])


class ProductFinalOptionForm(GenModelForm):
    products_pack = forms.ModelMultipleChoiceField(
        queryset=ProductFinal.objects.all(),
        label=_('Option products'),
        required=False,
        widget=MultiStaticSelect(
            attrs={'manytomany': True, }
        )
    )

    class Meta:
        model = ProductFinalOption
        exclude = []

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['product_final', 6],
                ['order', 3],
                ['active', 3],
                ['products_pack', 12],
            )
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (
                _('Details'), 12,
                ['product_final', 6],
                ['products_pack', 6],
                ['active', 6],
                ['order', 6],
            )
        ]
        return g


class ProductFinalOptionFormWithoutProduct(GenModelForm):
    products_pack = forms.ModelMultipleChoiceField(
        queryset=ProductFinal.objects.all(),
        label=_('Option products'),
        required=False,
        widget=MultiStaticSelect(
            attrs={'manytomany': True, }
        )
    )

    class Meta:
        model = ProductFinalOption
        exclude = ['product_final', ]

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['products_pack', 8],
                ['order', 2],
                ['active', 2],
            )
        ]
        return g


# MODELS
query = ""
forms_dyn = []
for info in MODELS:
    field = info[0]
    model = info[1]
    for lang_code in settings.LANGUAGES_DATABASES:
        exec("from codenerix_products.models import {}Text{}\n".format(model, lang_code))

        if model in ['ProductImage', 'ProductFinalImage']:
            label = _('Title and alternative text of the image')
        else:
            label = _('Description')
        query = """
class {model}TextForm{lang}(GenModelForm):\n
    class Meta:\n
        model={model}Text{lang}\n
        exclude = []\n
    def __groups__(self):\n
        return [(_('Details'),12,"""
        if lang_code == settings.LANGUAGES_DATABASES[0]:
            query += """
                ['description', 12, None, None, None, None, '{label}', ["ng-change=refresh_lang_field('description', '{model}TextForm', [{languages}])"]],
            )]\n"""
        else:
            query += """
                ['description', 12, None, None, None, None, '{label}'],
            )]\n"""
        exec(query.format(model=model, lang=lang_code, label=label, languages="'{}'".format("','".join(settings.LANGUAGES_DATABASES))))


# MODELS BRANDS
for info in MODELS_BRANDS:
    field = info[0]
    model = info[1]
    for lang_code in settings.LANGUAGES_DATABASES:
        query = "from codenerix_products.models import {}Text{}\n".format(model, lang_code)
        exec(query)
        query = """
class {model}TextForm{lang}(GenModelForm):\n
    class Meta:\n
        model={model}Text{lang}\n
        exclude = []\n
    def __groups__(self):\n
        return [(_('Details'),12,
                """
        if lang_code == settings.LANGUAGES_DATABASES[0]:
            query += """
                ['name', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('name', '{model}TextForm', [{languages}])"]],
                ['slug', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('slug', '{model}TextForm', [{languages}])"]],
                ['public', 4],
                ['description_short', 6, None, None, None, None, None, ["ng-blur=refresh_lang_field('description_short', '{model}TextForm', [{languages}])"]],
                ['description_long', 6, None, None, None, None, None, ["ng-blur=refresh_lang_field('description_long', '{model}TextForm', [{languages}])"]],
            ), (_('SEO'),12,
                ['meta_title', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('meta_title', '{model}TextForm', [{languages}])"]],
                ['meta_description', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('meta_description', '{model}TextForm', [{languages}])"]],
                ['meta_keywords', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('meta_keywords', '{model}TextForm', [{languages}])"]],
            )]\n"""
        else:
            query += """
                ['name', 4],
                ['slug', 4],
                ['public', 4],
                ['description_short', 6],
                ['description_long', 6],
            ), (_('SEO'),12,
                ['meta_title', 4],
                ['meta_description', 4],
                ['meta_keywords', 4],
            )]\n"""
        exec(query.format(model=model, lang=lang_code, languages="'{}'".format("','".join(settings.LANGUAGES_DATABASES))))


# MODELS PRODUCTS
for info in MODELS_PRODUCTS:
    field = info[0]
    model = info[1]
    for lang_code in settings.LANGUAGES_DATABASES:
        query = "from codenerix_products.models import {}Text{}\n".format(model, lang_code)
        exec(query)
        query = """
class {model}TextForm{lang}(GenModelForm):\n
    class Meta:\n
        model={model}Text{lang}\n
        exclude = []\n
    def __groups__(self):\n
        return [(_('Details'),12,
                """
        if lang_code == settings.LANGUAGES_DATABASES[0]:
            query += """
                ['name', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('name', '{model}TextForm', [{languages}])"]],
                ['slug', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('slug', '{model}TextForm', [{languages}])"]],
                ['public', 4],
                ['description_short', 6, None, None, None, None, None, ["ng-blur=refresh_lang_field('description_short', '{model}TextForm', [{languages}])"]],
                ['description_long', 6, None, None, None, None, None, ["ng-blur=refresh_lang_field('description_long', '{model}TextForm', [{languages}])"]],
            ), (_('SEO'),12,
                ['meta_title', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('meta_title', '{model}TextForm', [{languages}])"]],
                ['meta_description', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('meta_description', '{model}TextForm', [{languages}])"]],
                ['meta_keywords', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('meta_keywords', '{model}TextForm', [{languages}])"]],
                ['tags', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('tags', '{model}TextForm', [{languages}])"]],
            )]\n"""
        else:
            query += """
                ['name', 4],
                ['slug', 4],
                ['public', 4],
                ['description_short', 6],
                ['description_long', 6],
            ), (_('SEO'),12,
                ['meta_title', 4],
                ['meta_description', 4],
                ['meta_keywords', 4],
                ['tags', 4],
            )]\n"""
        exec(query.format(model=model, lang=lang_code, languages="'{}'".format("','".join(settings.LANGUAGES_DATABASES))))


# MODELS PRODUCTS
for info in MODELS_PRODUCTS_FINAL:
    field = info[0]
    model = info[1]
    for lang_code in settings.LANGUAGES_DATABASES:
        query = "from codenerix_products.models import {}Text{}\n".format(model, lang_code)
        exec(query)
        query = """
class {model}TextForm{lang}(GenModelForm):\n
    class Meta:\n
        model={model}Text{lang}\n
        exclude = []\n
    def __groups__(self):\n
        return [(_('Details'),12,
                """
        if lang_code == settings.LANGUAGES_DATABASES[0]:
            query += """
                ['name', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('name', '{model}TextForm', [{languages}])"]],
                ['slug', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('slug', '{model}TextForm', [{languages}])"]],
                ['public', 4],
                ['description_short', 6, None, None, None, None, None, ["ng-blur=refresh_lang_field('description_short', '{model}TextForm', [{languages}])"]],
                ['description_long', 6, None, None, None, None, None, ["ng-blur=refresh_lang_field('description_long', '{model}TextForm', [{languages}])"]],
                ['description_sample', 12, None, None, None, None, None, ["ng-blur=refresh_lang_field('description_sample', '{model}TextForm', [{languages}])"]],
            ), (_('SEO'),12,
                ['meta_title', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('meta_title', '{model}TextForm', [{languages}])"]],
                ['meta_description', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('meta_description', '{model}TextForm', [{languages}])"]],
                ['meta_keywords', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('meta_keywords', '{model}TextForm', [{languages}])"]],
                ['tags', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('meta_keywords', '{model}TextForm', [{languages}])"]],
            )]\n"""
        else:
            query += """
                ['name', 4],
                ['slug', 4],
                ['public', 4],
                ['description_short', 6],
                ['description_long', 6],
                ['description_sample', 12],
            ), (_('SEO'),12,
                ['meta_title', 4],
                ['meta_description', 4],
                ['meta_keywords', 4],
                ['tags', 4],
            )]\n"""
        exec(query.format(model=model, lang=lang_code, languages="'{}'".format("','".join(settings.LANGUAGES_DATABASES))))


# MODELS SLIDERS
query = ""
forms_dyn = []
for info in MODELS_SLIDERS:
    field = info[0]
    model = info[1]
    for lang_code in settings.LANGUAGES_DATABASES:
        query = "from codenerix_products.models import {}Text{}\n".format(model, lang_code)
        exec(query)
        query = """
class {model}TextForm{lang}(GenModelForm):\n
    class Meta:\n
        model={model}Text{lang}\n
        exclude = []\n
    def __groups__(self):\n
        return [(_('Details'),12,"""
        if lang_code == settings.LANGUAGES_DATABASES[0]:
            query += """
                ['title', 12, None, None, None, None, None, ["ng-blur=refresh_lang_field('title', '{model}TextForm', [{languages}])"]],
                ['description', 12, None, None, None, None, None, ["ng-blur=refresh_lang_field('description', '{model}TextForm', [{languages}])"]],
            )]\n"""
        else:
            query += """
                ['title', 12],
                ['description', 12],
            )]\n"""
        exec(query.format(model=model, lang=lang_code, languages="'{}'".format("','".join(settings.LANGUAGES_DATABASES))))

# MODELS SLUG
query = ""
forms_dyn = []
for info in MODELS_SLUG:
    field = info[0]
    model = info[1]
    for lang_code in settings.LANGUAGES_DATABASES:
        query = "from codenerix_products.models import {}Text{}\n".format(model, lang_code)
        exec(query)
        query = """
class {model}TextForm{lang}(GenModelForm):\n
    class Meta:\n
        model={model}Text{lang}\n
        exclude = []\n
    def __groups__(self):\n
        return [(_('Details'),12,"""
        if lang_code == settings.LANGUAGES_DATABASES[0]:
            query += """
                ['name', 12, None, None, None, None, None, ["ng-blur=refresh_lang_field('name', '{model}TextForm', [{languages}])"]],
                ['slug', 12, None, None, None, None, None, ["ng-blur=refresh_lang_field('slug', '{model}TextForm', [{languages}])"]],
                ['description', 12, None, None, None, None, None, ["ng-blur=refresh_lang_field('description', '{model}TextForm', [{languages}])"]],
            ), (_('SEO'),12,
                ['meta_title', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('meta_title', '{model}TextForm', [{languages}])"]],
                ['meta_description', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('meta_description', '{model}TextForm', [{languages}])"]],
                ['meta_keywords', 4, None, None, None, None, None, ["ng-blur=refresh_lang_field('meta_keywords', '{model}TextForm', [{languages}])"]],
            )]\n"""
        else:
            query += """
                ['name', 12],
                ['slug', 12],
                ['description', 12],
            ), (_('SEO'),12,
                ['meta_title', 4],
                ['meta_description', 4],
                ['meta_keywords', 4],
            )]\n"""

        exec(query.format(model=model, lang=lang_code, languages="'{}'".format("','".join(settings.LANGUAGES_DATABASES))))
